pub trait ToBytes {
// Required method
fn to_bytes(&self) -> Vec<u8> ⓘ;
}Expand description
A trait to convert a value into a byte slice that can be appended to a Builder.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".